@@ -3,15 +3,15 @@ A module for creating channels at runtime.
 """
 
 # built-in
+from typing import Any as _Any
 from typing import Union as _Union
 from typing import cast as _cast
 
 # third-party
 from vcorelib.namespace import Namespace as _Namespace
 
-from runtimepy.channel import FloatChannel as _FloatChannel
-
 # internal
+from runtimepy.channel import FloatChannel as _FloatChannel
 from runtimepy.channel.environment.base import (
     BaseChannelEnvironment as _BaseChannelEnvironment,
 )
@@ -23,8 +23,10 @@ from runtimepy.channel.environment.base import (
 )
 from runtimepy.channel.environment.base import ChannelResult as _ChannelResult
 from runtimepy.enum import RuntimeEnum as _RuntimeEnum
+from runtimepy.enum.registry import DEFAULT_ENUM_PRIMITIVE
 from runtimepy.enum.type import EnumTypelike as _EnumTypelike
 from runtimepy.mapping import EnumMappingData as _EnumMappingData
+from runtimepy.primitives import Primitive
 from runtimepy.primitives import Primitivelike as _Primitivelike
 from runtimepy.registry.name import RegistryKey as _RegistryKey
 
@@ -35,7 +37,7 @@ class CreateChannelEnvironment(_BaseChannelEnvironment):
     def channel(
         self,
         name: str,
-        kind: _Primitivelike,
+        kind: _Union[Primitive[_Any], _Primitivelike],
         commandable: bool = False,
         enum: _Union[_RegistryKey, _RuntimeEnum] = None,
         namespace: _Namespace = None,
@@ -54,12 +56,17 @@ class CreateChannelEnvironment(_BaseChannelEnvironment):
             name, kind, commandable=commandable, enum=enum
         )
         assert result is not None, f"Can't create channel '{name}'!"
+
+        # Keep track of any new enum channels.
+        if enum is not None:
+            self.channel_enums[result] = self.enums[enum]
+
         return self[name]
 
     def int_channel(
         self,
         name: str,
-        kind: _Primitivelike = "uint32",
+        kind: _Union[Primitive[_Any], _Primitivelike] = "uint32",
         commandable: bool = False,
         enum: _Union[_RegistryKey, _RuntimeEnum] = None,
         namespace: _Namespace = None,
@@ -75,7 +82,7 @@ class CreateChannelEnvironment(_BaseChannelEnvironment):
     def bool_channel(
         self,
         name: str,
-        kind: _Primitivelike = "bool",
+        kind: _Union[Primitive[_Any], _Primitivelike] = "bool",
         commandable: bool = False,
         enum: _Union[_RegistryKey, _RuntimeEnum] = None,
         namespace: _Namespace = None,
@@ -91,7 +98,7 @@ class CreateChannelEnvironment(_BaseChannelEnvironment):
     def float_channel(
         self,
         name: str,
-        kind: _Primitivelike = "float",
+        kind: _Union[Primitive[_Any], _Primitivelike] = "float",
         commandable: bool = False,
         namespace: _Namespace = None,
     ) -> _FloatChannel:
@@ -109,6 +116,7 @@ class CreateChannelEnvironment(_BaseChannelEnvironment):
         kind: _EnumTypelike,
         items: _EnumMappingData = None,
         namespace: _Namespace = None,
+        primitive: str = DEFAULT_ENUM_PRIMITIVE,
     ) -> _RuntimeEnum:
         """Create a new enum from the environment."""
 
@@ -116,6 +124,7 @@ class CreateChannelEnvironment(_BaseChannelEnvironment):
             self.namespace(name=name, namespace=namespace),
             kind=kind,
             items=items,
+            primitive=primitive,
         )
         assert result is not None, f"Can't create enum '{name}'!"
         return result
