@@ -1,7 +1,7 @@
 # =====================================
 # generator=datazen
-# version=3.1.2
-# hash=40f5c85d844b6d42a5dd10ff46c82cdd
+# version=3.1.3
+# hash=c2bc26deadfa7cc275e815f499693863
 # =====================================
 
 """
@@ -10,12 +10,14 @@ This package's command-line entry-point (boilerplate).
 
 # built-in
 import argparse
-import logging
 import os
 from pathlib import Path
 import sys
 from typing import List
 
+# third-party
+from vcorelib.logging import init_logging, logging_args
+
 # internal
 from runtimepy import DESCRIPTION, VERSION
 from runtimepy.app import add_app_args, entry
@@ -38,12 +40,7 @@ def main(argv: List[str] = None) -> int:
         action="version",
         version=f"%(prog)s {VERSION}",
     )
-    parser.add_argument(
-        "-v",
-        "--verbose",
-        action="store_true",
-        help="set to increase logging verbosity",
-    )
+    logging_args(parser)
     parser.add_argument(
         "-C",
         "--dir",
@@ -63,10 +60,8 @@ def main(argv: List[str] = None) -> int:
         args.dir = args.dir.resolve()
 
         # initialize logging
-        log_level = logging.DEBUG if args.verbose else logging.INFO
-        logging.basicConfig(
-            level=log_level,
-            format="%(name)-36s - %(levelname)-6s - %(message)s",
+        init_logging(
+            args, default_format="%(name)-36s - %(levelname)-6s - %(message)s"
         )
 
         # change to the specified directory
