@@ -15,9 +15,13 @@ from runtimepy.task import PeriodicTask, PeriodicTaskManager
 class ArbiterTask(PeriodicTask):
     """A base class for arbiter periodic tasks."""
 
+    app: AppInfo
+
     async def init(self, app: AppInfo) -> None:
         """Initialize this task with application information."""
 
+        self.app = app
+
 
 class ArbiterTaskManager(PeriodicTaskManager[ArbiterTask]):
     """A task-manger class for the connection arbiter."""
