@@ -12,17 +12,21 @@ from typing import Union as _Union
 
 # third-party
 from vcorelib.asyncio import log_exceptions as _log_exceptions
-from vcorelib.logging import LoggerMixin as _LoggerMixin
 from vcorelib.logging import LoggerType as _LoggerType
 
 # internal
-from runtimepy.net.metrics import ConnectionMetrics
+from runtimepy.channel.environment import ChannelEnvironment
+from runtimepy.channel.environment.command import ChannelCommandProcessor
+from runtimepy.metrics import ConnectionMetrics
+from runtimepy.mixins.environment import ChannelEnvironmentMixin
+from runtimepy.mixins.logging import LoggerMixinLevelControl
+from runtimepy.primitives import Bool
 from runtimepy.primitives.byte_order import DEFAULT_BYTE_ORDER, ByteOrder
 
 BinaryMessage = _Union[bytes, bytearray, memoryview]
 
 
-class Connection(_LoggerMixin, _ABC):
+class Connection(LoggerMixinLevelControl, ChannelEnvironmentMixin, _ABC):
     """A connection interface."""
 
     uses_text_tx_queue = True
@@ -30,11 +34,16 @@ class Connection(_LoggerMixin, _ABC):
 
     byte_order: ByteOrder = DEFAULT_BYTE_ORDER
 
-    def __init__(self, logger: _LoggerType) -> None:
+    def __init__(
+        self,
+        logger: _LoggerType,
+        env: ChannelEnvironment = None,
+        add_metrics: bool = True,
+    ) -> None:
         """Initialize this connection."""
 
-        super().__init__(logger=logger)
-        self._enabled = True
+        LoggerMixinLevelControl.__init__(self, logger=logger)
+        self._enabled = Bool(True)
 
         # A queue for out-going text messages. Connections that don't use
         # this can set 'uses_text_tx_queue' to False to avoid scheduling a
@@ -48,11 +57,21 @@ class Connection(_LoggerMixin, _ABC):
         self._binary_messages: _asyncio.Queue[BinaryMessage] = _asyncio.Queue()
         self.tx_binary_hwm: int = 0
 
-        self.metrics = ConnectionMetrics()
-
         self._tasks: _List[_asyncio.Task[None]] = []
         self.initialized = _asyncio.Event()
         self.disabled_event = _asyncio.Event()
+
+        self.metrics = ConnectionMetrics()
+
+        ChannelEnvironmentMixin.__init__(self, env=env)
+        self.setup_level_channel(self.env)
+        self.command = ChannelCommandProcessor(self.env, self.logger)
+        if add_metrics:
+            self.register_connection_metrics(self.metrics)
+
+        # State.
+        self.env.channel("enabled", self._enabled)
+
         self.init()
 
     def init(self) -> None:
@@ -118,7 +137,7 @@ class Connection(_LoggerMixin, _ABC):
         if self._enabled:
             self.logger.info("Disabling connection: '%s'.", reason)
             self.disable_extra()
-            self._enabled = False
+            self._enabled.value = False
 
             # Cancel tasks.
             for task in self._tasks:
