@@ -4,7 +4,6 @@ A module implementing a simple periodic-task interface.
 
 # internal
 from runtimepy.task.basic.manager import PeriodicTaskManager
-from runtimepy.task.basic.metrics import PeriodicTaskMetrics
 from runtimepy.task.basic.periodic import PeriodicTask
 
-__all__ = ["PeriodicTask", "PeriodicTaskMetrics", "PeriodicTaskManager"]
+__all__ = ["PeriodicTask", "PeriodicTaskManager"]
